@@ -1,9 +1,9 @@
 package Calendar::Indonesia::Holiday;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-16'; # DATE
+our $DATE = '2021-03-07'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.335'; # VERSION
+our $VERSION = '0.336'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1452,7 +1452,7 @@ gen_modified_sub(
 
 $SPEC{list_idn_workdays} = {
     v => 1.1,
-    summary => '',
+    summary => 'List Indonesian workdays (non-holidays) in calendar',
     args => {
         year       => {schema=>'int*'},
         month      => {schema=>['int*', between=>[1, 12]]},
@@ -1602,7 +1602,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.335 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-01-16.
+This document describes version 0.336 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-03-07.
 
 =head1 SYNOPSIS
 
@@ -2302,7 +2302,7 @@ Usage:
 
  list_idn_workdays(%args) -> [status, msg, payload, meta]
 
-.
+List Indonesian workdays (non-holidays) in calendar.
 
 This function is not exported.
 
@@ -2412,7 +2412,7 @@ Source repository is at L<https://github.com/perlancar/perl-Calendar-Indonesia-H
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Calendar-Indonesia-Holiday/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Calendar-Indonesia-Holiday>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -2431,7 +2431,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
